@@ -88,6 +88,24 @@ def add_hyphens(tavut, sana, hyphen, margin):
 			tavutettava += hyphen
 	return tavutettava
 
+def hyp_paska(tavuttamaton_osa, margin=2, hyphen='\u00AD'):
+	tavutettu = ''
+	while len(tavuttamaton_osa) > 0:
+		raja_asti = tavuttamaton_osa.find('[[[')
+		if raja_asti != -1:
+			tavutettava_osa = tavuttamaton_osa[:raja_asti]
+			tavuttamaton_osa = tavuttamaton_osa[raja_asti+3:]
+			tavutettu += hyp_html(tavutettava_osa, margin, hyphen)
+		else:
+			tavutettava_osa = tavuttamaton_osa
+			tavuttamaton_osa = ''
+			tavutettu += hyp_html(tavutettava_osa, margin, hyphen)
+		raja_alkaen = tavuttamaton_osa.find(']]]')
+		if raja_alkaen != -1:
+			tavutettu += tavuttamaton_osa[:raja_alkaen]
+			tavuttamaton_osa = tavuttamaton_osa[raja_alkaen+3:]
+	return tavutettu
+
 def hyp_html(tavuttamaton_osa, margin=2, hyphen='\u00AD'):
 	tavutettu = ''
 	while len(tavuttamaton_osa) > 0:
@@ -123,7 +141,7 @@ def hyp_text(text, margin=2, hyphen='\u00AD'):
 	return valmis_teksti
 	
 
-def hyphenate(text, margin=2, skip_html=False, hyphen='\u00AD'):
+def hyphenate(text, margin=2, skip_html=False, hyphen='\u00AD', skip_brackets=False):
 	"""hyphenate_finnish(text, margin=2, skip_html=False, hyphen='\u00AD')
 
 	Hyphenates Finnish text with Unicode soft hyphens. (U+00AD) Mainly intended for server-
@@ -143,7 +161,9 @@ def hyphenate(text, margin=2, skip_html=False, hyphen='\u00AD'):
 	if margin < 1:
 		margin = 1
 	
-	if skip_html:
+	if skip_brackets:
+		return hyp_paska(text, margin, hyphen)
+	elif skip_html:
 		return hyp_html(text, margin, hyphen)
 	else:
 		return hyp_text(text, margin, hyphen)
